@@ -61,6 +61,8 @@ AUTH_TYPES = {'mepis': 'su',
               'zorinos': 'sudo',
               'zorin' : 'sudo',
               'debiangnu/linux' : 'su',
+              'mxlinux' : 'su',
+              'elementaryos' : 'sudo',
               'openbsd' : 'su',
               }
 
@@ -81,6 +83,7 @@ def showPasswordPrompt(prompt):
 # TBD this function shoud be removed once distro class implemented
 def get_distro_name():
     os_name = None
+    distro_release_name = str()
     try:
         import platform
     except ImportError:
@@ -89,9 +92,13 @@ def get_distro_name():
     try:
         os_name = platform.dist()[0]
     except AttributeError:
-        import distro
-        os_name = distro.linux_distribution()[0]
-
+        try:
+            import distro
+            os_name = distro.linux_distribution()[0]
+            distro_release_name = distro.distro_release_attr('name')
+        except:
+            os_name = None
+            
     if not os_name:
         name = os.popen('lsb_release -i | cut -f 2')
         os_name = name.read().strip()
@@ -106,12 +113,16 @@ def get_distro_name():
         os_name = platform.system()
 
     os_name = os_name.lower()
+    if 'MX' in distro_release_name:
+        os_name = "mxlinux"
     if "redhatenterprise" in os_name:
-        os_name = 'rhel'
+        os_name = 'rhel'    
     elif "suse" in os_name:
         os_name = 'suse'
     elif "arch" in os_name:
-         os_name = 'manjarolinux'
+        os_name = 'manjarolinux'
+    elif "fedora" in os_name:
+        os_name = 'fedora'
 
     return os_name
 
